===============================
GAEK: Google App Engine Kit
===============================

.. image:: https://img.shields.io/travis/erichiggins/gaek.svg
        :target: https://travis-ci.org/erichiggins/gaek

.. image:: https://img.shields.io/pypi/v/gaek.svg
        :target: https://pypi.python.org/pypi/gaek


A collection of useful tools for Python apps running on Google App Engine.

* Free software: BSD license
* Documentation: https://gaek.readthedocs.org.

Features
--------

* TODO




History
-------

0.1.0 (2015-06-29)
---------------------

* First release on PyPI.


